from datetime import datetime
import pymongo, time, requests, json

"""
Netdata Mongo

This script requests data from the Netdata API in JSON format,
parses the result, and stores it in a MongoDB database. 
"""

db_name = 'netdata'
collection_name = 'jupiter'

# MongoDB
client = pymongo.MongoClient('10.6.0.1', 27017)
db = client[db_name]

while(True):

    # Netdata
    my_url = 'http://10.6.0.1:19999/api/v1/allmetrics?format=json'
    r = requests.get(url=my_url)
    d = r.json()

    collection = db[collection_name]

    # Use each key in the original Netdata bundle
    # as a "key prefix"
    to_insert = {}
    for key in d.keys():
        
        data = d[key]

        prefix = data['name']
        timestamp = datetime.fromtimestamp(data['last_updated'])

        # values_data is list of dictionaries: key is label, value is numerical value
        values_data = list(data['dimensions'].values())

        # Assemble final key-value pair going into MongoDB
        for v in values_data:
            this_label = prefix + "." + v['name']
            this_value = v['value']
            to_insert[this_label] = this_value
        to_insert['timestamp'] = timestamp

    # Insert into MongoDB
    try:
        collection.insert(to_insert, check_keys=False)
    except pymongo.errors.OperationFailure as e:
        print(e.code)
        print(e.details)

    print("Inserted document into collection.")
    time.sleep(10)

